def drop_missing(df, subset=None):
    return df.dropna(subset=subset)


def drop_duplicates(df):
    return df.drop_duplicates()


def detect_outliers_zscore(df, column, threshold=3):
    from scipy.stats import zscore
    return df[(zscore(df[column].dropna()) < threshold)]


def drop_low_variance_columns(df, threshold=0.0):
    from sklearn.feature_selection import VarianceThreshold
    selector = VarianceThreshold(threshold)
    selector.fit(df.select_dtypes(include=['float64', 'int64']))
    cols = df.select_dtypes(include=['float64', 'int64']).columns[selector.get_support()]
    return df[cols]


def drop_columns_single_value(df):
    return df.loc[:, df.nunique() > 1]


def drop_columns_low_uniqueness(df, threshold=0.01):
    return df.loc[:, df.nunique() / len(df) > threshold]


def identify_duplicate_rows(df):
    return df[df.duplicated()]


def remove_duplicate_rows(df):
    return df.drop_duplicates()


from .importation import load_csv, load_excel, load_sql
from .nettoyage import drop_missing, drop_duplicates, detect_outliers_zscore, \
    drop_low_variance_columns, drop_columns_single_value, drop_columns_low_uniqueness, \
    identify_duplicate_rows, remove_duplicate_rows
from .enrichissement import map_values, encode_categorical
from .transformation import scale_data, normalize_column, summary_statistics, plot_boxplot, \
    identify_outliers_std, remove_outliers_std, remove_outliers_iqr
from .outliers import detect_outliers_lof, regression_without_outliers
from .missing_values import count_missing, replace_zeros_with_nan, drop_missing_rows, lda_on_clean_data
from .feature_selection import prepare_features_target, split_train_test, select_features, train_model

__all__ = [
    'load_csv', 'load_excel', 'load_sql',
    'drop_missing', 'drop_duplicates', 'detect_outliers_zscore',
    'drop_low_variance_columns', 'drop_columns_single_value', 'drop_columns_low_uniqueness',
    'identify_duplicate_rows', 'remove_duplicate_rows',
    'map_values', 'encode_categorical',
    'scale_data', 'normalize_column', 'summary_statistics', 'plot_boxplot',
    'identify_outliers_std', 'remove_outliers_std', 'remove_outliers_iqr',
    'detect_outliers_lof', 'regression_without_outliers',
    'count_missing', 'replace_zeros_with_nan', 'drop_missing_rows', 'lda_on_clean_data',
    'prepare_features_target', 'split_train_test', 'select_features', 'train_model'
]



from sklearn.preprocessing import StandardScaler, MinMaxScaler
import seaborn as sns
import matplotlib.pyplot as plt
import numpy as np


def scale_data(df, columns, method='standard'):
    scaler = StandardScaler() if method == 'standard' else MinMaxScaler()
    df[columns] = scaler.fit_transform(df[columns])
    return df


def normalize_column(df, column):
    df[column] = df[column] / df[column].abs().max()
    return df


def summary_statistics(df):
    return df.describe()


def plot_boxplot(df, column):
    sns.boxplot(x=df[column])
    plt.show()


def identify_outliers_std(df, column, threshold=3):
    mean = df[column].mean()
    std = df[column].std()
    upper = mean + threshold * std
    lower = mean - threshold * std
    return df[(df[column] > upper) | (df[column] < lower)]


def remove_outliers_std(df, column, threshold=3):
    mean = df[column].mean()
    std = df[column].std()
    upper = mean + threshold * std
    lower = mean - threshold * std
    return df[(df[column] <= upper) & (df[column] >= lower)]


def remove_outliers_iqr(df, column):
    Q1 = df[column].quantile(0.25)
    Q3 = df[column].quantile(0.75)
    IQR = Q3 - Q1
    lower = Q1 - 1.5 * IQR
    upper = Q3 + 1.5 * IQR
    return df[(df[column] >= lower) & (df[column] <= upper)]



from sklearn.neighbors import LocalOutlierFactor
from sklearn.linear_model import LinearRegression
from sklearn.metrics import mean_squared_error
from sklearn.model_selection import train_test_split


def detect_outliers_lof(X, n_neighbors=20):
    lof = LocalOutlierFactor(n_neighbors=n_neighbors)
    yhat = lof.fit_predict(X)
    return yhat


def regression_without_outliers(X, y):
    yhat = detect_outliers_lof(X)
    X_clean = X[yhat == 1]
    y_clean = y[yhat == 1]
    model = LinearRegression().fit(X_clean, y_clean)
    y_pred = model.predict(X_clean)
    error = mean_squared_error(y_clean, y_pred, squared=False)
    return model, error



import numpy as np
from sklearn.model_selection import train_test_split
from sklearn.feature_selection import SelectKBest, f_classif
from sklearn.linear_model import LogisticRegression


def prepare_features_target(df, features, target):
    X = df[features].values
    y = df[target].values
    return X, y


def split_train_test(X, y, test_size=0.2, random_state=None):
    return train_test_split(X, y, test_size=test_size, random_state=random_state)


def select_features(X_train, y_train, k=5):
    selector = SelectKBest(score_func=f_classif, k=k)
    X_new = selector.fit_transform(X_train, y_train)
    return X_new, selector

def train_model(X_train, y_train):
    model = LogisticRegression(max_iter=1000).fit(X_train, y_train)
    return model


import pandas as pd
import mysql.connector
from sqlalchemy import create_engine


def load_csv(path, **kwargs):
    return pd.read_csv(path, **kwargs)


def load_excel(path, sheet_name=0, **kwargs):
    return pd.read_excel(path, sheet_name=sheet_name, **kwargs)


def load_sql(query, connection_string):
    engine = create_engine(connection_string)
    with engine.connect() as conn:
        return pd.read_sql(query, conn)



from setuptools import setup, find_packages

setup(
    name="kaoWispre",
    version="0.3.1",
    packages=find_packages(),
    install_requires=[
        # Core dependencies
        "pandas>=1.3.0",
        "numpy>=1.21.0",
        "scipy>=1.7.0",
        
        # Preprocessing
        "scikit-learn>=1.0.0",
        "imbalanced-learn>=0.9.0",
        "fancyimpute>=0.7.0",
        "category_encoders>=2.4.0",
        
        # Visualisation (optionnel)
        "matplotlib>=3.5.0",
        "seaborn>=0.11.2",

        # Database connectivity
        "mysql-connector-python>=8.0.0",
        "sqlalchemy>=1.4.0",
        "pymysql>=1.0.0", 
        
        # Utilitaires
        "tqdm>=4.64.0",
        "python-dotenv>=0.19.0",
    ],
    extras_require={
        'dev': [
            "pytest>=7.0.0",
            "pytest-cov>=3.0.0",
            "flake8>=4.0.0",
            "black>=22.0.0",
        ],
        'docs': [
            "sphinx>=5.0.0",
            "sphinx-rtd-theme>=1.0.0",
        ]
    },
    python_requires='>=3.8',
    author="Votre Nom",
    author_email="votre@email.com",
    description="Une bibliothèque complète de prétraitement de données",
    long_description="Bibliothèque Python pour le prétraitement automatisé de données (nettoyage, transformation, feature engineering, etc.)",  # Description textuelle simple
    long_description_content_type="text/plain",  # Type de contenu explicite
    url="https://github.com/votrecompte/preprocessor",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)


import numpy as np
def count_missing(df):
    return df.isna().sum()


def replace_zeros_with_nan(df):
    df = df.replace(0, np.nan)
    return df

def replace_unknowns_with_nan(df):
    df = df.replace(['UNKNOWN', 'unknown', 'Unknown'], np.nan)
    return df
    

def drop_missing_rows(df):
    return df.dropna()


def lda_on_clean_data(X, y):
    from sklearn.discriminant_analysis import LinearDiscriminantAnalysis
    model = LinearDiscriminantAnalysis().fit(X, y)
    return model
